/*
 * Copyright (c) 2021, GlassEditor. All rights reserved.
 *
 * This code is part of the GlassEditor API. You can see the terms 
 * of use at glasseditor.com/terms.
 * 
 * If you have any questions or problems with it please contact us
 * at glasseditor.com/contact.
 */
package com.glasseditor.api;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.concurrent.TimeUnit;

@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
public @interface Test {
	/**
	 * The set of groups that this test belongs to.
	 * Sub-groups can be made by adding a / to the parent group name,
	 * for example "parent/child"
	 */
	String[] value() default "";
	/**
	 * true if the test should run in parrallel with other tests on other threads.
	 */
	boolean parallel() default true;
	/**
	 * true if the test should start a new unique jvm instance to run isolated.
	 */
	boolean uniqueVM() default false;
	/**
	 * number of {@link #timeoutUnit}s to wait before attempting to stop the test.
	 */
	long timeout() default 10;
	/**
	 * units for {@link #timeout}.
	 */
	TimeUnit timeoutUnit() default TimeUnit.SECONDS;
}
